@@ -1,8 +1,9 @@
 from k3cloud_webapi_sdk.main import K3CloudApiSdk
 from pyrda.dbms.rds import RdClient
-import .operation as db
-import .utility as ut
-import .metadata as mt
+from .operation import *
+from .utility import *
+from .metadata import *
+
 def returnSale(startDate,endDate):
 
     app2 = RdClient(token='4D181CAB-4CE3-47A3-8F2B-8AB11BB6A227')
@@ -10,11 +11,11 @@ def returnSale(startDate,endDate):
 
     # ut.writeSRC(startDate,endDate,app3)
 
-    data = db.getCode(app3)
+    data = getCode(app3)
 
     if data:
 
-        res = ut.classification_process(app3, data)
+        res = classification_process(app3, data)
         # 新账套
         option1 = {
             "acct_id": '62777efb5510ce',
@@ -27,6 +28,6 @@ def returnSale(startDate,endDate):
 
         api_sdk = K3CloudApiSdk()
 
-        msg=mt.associated(app2, api_sdk, option1, res,app3)
+        msg=associated(app2, api_sdk, option1, res,app3)
 
         return msg
